@@ -9,11 +9,11 @@ use parent 'Exporter';
 #------------------------------------------------------------------------------
 #   Mojo DBI 版本信息
 #------------------------------------------------------------------------------
-our $VERSION = '0.0.2';
+our $VERSION = '0.0.3';
 our @EXPORT  = qw "vue_crud_get";
 
 #------------------------------------------------------------------------------
-# 导出函数到外部，用来适配 VUE CRUD 数据结构
+# 导出函数到外部，用来适配 VUE CRUD 数据结构 -- 语句适配 postgresql
 #------------------------------------------------------------------------------
 sub vue_crud_get {
   # 接收外部入参 - 前端查询变量 和 查询对象
@@ -41,7 +41,7 @@ sub vue_crud_get {
 
   # 初始化 SQL 语句变量
   my $sql_str   = "SELECT * FROM $table";
-  my $order_str = " ORDER BY $sort LIMIT $offset, $size";
+  my $order_str = " ORDER BY $sort OFFSET $offset LIMIT $size";
   my $name_str  = " WHERE $query LIKE \'%$query_str%\'" if defined $query_str;
   my $time_str  = " create_time BETWEEN  \'$time->[0]\' AND \'$time->[1]\'" if $time;
 
